@@ -1,20 +1,29 @@
 # moosic/client/cli/dispatcher.py - The code for dispatching moosic commands.
 #
-# Copyright (C) 2001-2003 Daniel Pearson <daniel@nanoo.org>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# This is free and unencumbered software released into the public domain.
+# 
+# Anyone is free to copy, modify, publish, use, compile, sell, or
+# distribute this software, either in source code form or as a compiled
+# binary, for any purpose, commercial or non-commercial, and by any
+# means.
+# 
+# In jurisdictions that recognize copyright laws, the author or authors
+# of this software dedicate any and all copyright interest in the
+# software to the public domain. We make this dedication for the benefit
+# of the public at large and to the detriment of our heirs and
+# successors. We intend this dedication to be an overt act of
+# relinquishment in perpetuity of all present and future rights to this
+# software under copyright law.
+# 
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+# IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
+# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
+# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
+# OTHER DEALINGS IN THE SOFTWARE.
+# 
+# For more information, please refer to <http://unlicense.org/>
 
 
 __all__ = ("dispatcher", "command_categories", "get_command_docs", "check_args")
@@ -26,14 +35,17 @@ from moosic.utilities import *
 from moosic.client.factory import startServer
 from moosic import VERSION
 
+# Portability note: the Unix "find" program is required to be present on the
+# system. It is almost unthinkable that you could have a Unix system that
+# didn't have the "find" command, but you never know.
 try:
     import subprocess
     def call_find(dir):
         return subprocess.Popen(['find',dir,'-follow','-type','f','-print'], \
-                stdout=PIPE).stdout.readlines()
+                stdout=subprocess.PIPE).stdout.readlines()
 except ImportError:
     def call_find(dir):
-        return os.popen('find "%s" -follow -type f -print' % dir).readlines()
+        return os.popen('find "%s" -follow -type f -print' % sh_escape(dir)).readlines()
 
 # Define the True and False constants if they don't already exist.
 try: True
@@ -200,8 +212,7 @@ def process_filelist(moosic, arglist, opts):
         if opts['ignore-case']:
             arglist = [i + '(?i)' for i in arglist]
         # Get a list of filenames which are eligible for auto-finding.
-        dir = sh_escape(opts['music-dir'])
-        files = call_find(dir)
+        files = call_find(opts['music-dir'])
         files.sort()
         # Strip off the trailing EOL character.
         files = [item[:-1] for item in files]
@@ -217,8 +228,7 @@ def process_filelist(moosic, arglist, opts):
         # Simplify the strings to be sought after.
         arglist = [simplify(a) for a in arglist]
         # Get a list of filenames which are eligible for auto-finding.
-        dir = sh_escape(opts['music-dir'])
-        files = call_find(dir)
+        files = call_find(opts['music-dir'])
         # Strip off the trailing EOL character.
         files = [item[:-1] for item in files]
         # Simplify the filenames to be searched through, and map each simplified
@@ -251,14 +261,7 @@ def process_filelist(moosic, arglist, opts):
         pos = 0
         while pos < len(arglist):
             if os.path.isdir(arglist[pos]):
-                dir = arglist.pop(pos)
-                # Escape evil characters in the directory name.
-                dir = sh_escape(dir)
-                # Portability note: the Unix "find" program is required to
-                # be present on the system. It is almost unthinkable that
-                # you could have a Unix system that didn't have the "find"
-                # command, but you never know.
-                contents = call_find(dir)
+                contents = call_find(arglist.pop(pos))
                 # Strip off the trailing EOL character.
                 contents = [item[:-1] for item in contents]
                 if opts['shuffle-dir']:
@@ -586,10 +589,7 @@ def wipe(moosic, arglist, opts):
     if moosic.is_queue_running():
         moosic.halt_queue()
         was_running = True
-    # skip() must be called before clear() to produce correct behavior while in
-    # loop mode.  Otherwise, the current song would not get removed from the
-    # queue.
-    moosic.skip()
+    moosic.stop()
     moosic.clear()
     if was_running:
         moosic.run_queue()
@@ -1180,6 +1180,8 @@ dispatcher[unmangle(f.__name__)] = f
 
 def goto(moosic, arglist, opts):
     'goto <regex> - Jump to the first song in the queue that matches the regex.'
+    if opts['ignore-case']:
+        arglist = [i + '(?i)' for i in arglist]
     queue = moosic.list()
     dest = 1
     while queue:
@@ -1203,6 +1205,8 @@ dispatcher[unmangle(f.__name__)] = f
 
 def gobackto(moosic, arglist, opts):
     'gobackto <regex> - Jump to the previous song that matches the regex.'
+    if opts['ignore-case']:
+        arglist = [i + '(?i)' for i in arglist]
     history = moosic.history()
     dest = 1
     while history:
